<?php
/**
 * License: GPLv3
 * License URI: https://www.gnu.org/licenses/gpl.txt
 * Copyright 2014-2021 Jean-Sebastien Morisset (https://wpsso.com/)
 */

if ( ! defined( 'ABSPATH' ) ) {

	die( 'These aren\'t the droids you\'re looking for.' );
}

if ( ! class_exists( 'WpssoPlmConfig' ) ) {

	class WpssoPlmConfig {

		public static $cf = array(
			'plugin' => array(
				'wpssoplm' => array(			// Plugin acronym.
					'version'     => '6.2.1',	// Plugin version.
					'opt_version' => '45',		// Increment when changing default option values.
					'short'       => 'WPSSO PLM',	// Short plugin name.
					'name'        => 'WPSSO Place and Local SEO Markup',
					'desc'        => 'Manage Schema Places and Local SEO for Facebook / Open Graph, Pinterest, and Google Local Business.',
					'slug'        => 'wpsso-plm',
					'base'        => 'wpsso-plm/wpsso-plm.php',
					'update_auth' => '',		// No premium version.
					'text_domain' => 'wpsso-plm',
					'domain_path' => '/languages',

					/**
					 * Required plugin and its version.
					 */
					'req' => array(
						'wpsso' => array(
							'name'          => 'WPSSO Core',
							'home'          => 'https://wordpress.org/plugins/wpsso/',
							'plugin_class'  => 'Wpsso',
							'version_const' => 'WPSSO_VERSION',
							'min_version'   => '9.1.0',
						),
					),

					/**
					 * URLs or relative paths to plugin banners and icons.
					 */
					'assets' => array(

						/**
						 * Icon image array keys are '1x' and '2x'.
						 */
						'icons' => array(
							'1x' => 'images/icon-128x128.png',
							'2x' => 'images/icon-256x256.png',
						),
					),

					/**
					 * Library files loaded and instantiated by WPSSO.
					 */
					'lib' => array(
						'submenu' => array(
							'plm-general' => 'Places',
						),
					),
				),
			),

			/**
			 * Additional add-on setting options.
			 */
			'opt' => array(
				'defaults' => array(
					'plm_place_edit_id' => 0,	// Edit a Place.
				),
				'def_plm_place' => array(
					'plm_place_schema_type'              => 'local.business',	// Place Schema Type.
					'plm_place_name'                     => '',			// Place Name.
					'plm_place_name_alt'                 => '',			// Place Altername Name.
					'plm_place_desc'                     => '',			// Place Description.
					'plm_place_street_address'           => '',			// Street Address.
					'plm_place_po_box_number'            => '',			// P.O. Box Number.
					'plm_place_city'                     => '',			// City.
					'plm_place_region'                   => '',			// State / Province.
					'plm_place_postal_code'              => '',			// Zip / Postal Code.
					'plm_place_country'                  => '',			// Country.
					'plm_place_phone'                    => '',			// Telephone.
					'plm_place_latitude'                 => '',			// Place Latitude.
					'plm_place_longitude'                => '',			// Place Longitude.
					'plm_place_altitude'                 => '',			// Place Altitude.
					'plm_place_img_id'                   => '',			// Place Image ID.
					'plm_place_img_id_lib'               => 'wp',
					'plm_place_img_url'                  => '',			// or Place Image URL.
					'plm_place_timezone'                 => 'UTC',			// Place Timezone.
					'plm_place_day_sunday_open'          => 'none',
					'plm_place_day_sunday_close'         => 'none',
					'plm_place_day_monday_open'          => 'none',
					'plm_place_day_monday_close'         => 'none',
					'plm_place_day_tuesday_open'         => 'none',
					'plm_place_day_tuesday_close'        => 'none',
					'plm_place_day_wednesday_open'       => 'none',
					'plm_place_day_wednesday_close'      => 'none',
					'plm_place_day_thursday_open'        => 'none',
					'plm_place_day_thursday_close'       => 'none',
					'plm_place_day_friday_open'          => 'none',
					'plm_place_day_friday_close'         => 'none',
					'plm_place_day_saturday_open'        => 'none',
					'plm_place_day_saturday_close'       => 'none',
					'plm_place_day_publicholidays_open'  => 'none',
					'plm_place_day_publicholidays_close' => 'none',
					'plm_place_midday_close'             => 'none',
					'plm_place_midday_open'              => 'none',
					'plm_place_season_from_date'         => '',
					'plm_place_season_to_date'           => '',
					'plm_place_service_radius'           => '',			// Service Radius.
					'plm_place_currencies_accepted'      => '',			// Currencies Accepted.
					'plm_place_payment_accepted'         => '',			// Payment Accepted.
					'plm_place_price_range'              => '',			// Price Range.
					'plm_place_accept_res'               => 0,			// Accepts Reservations.
					'plm_place_cuisine'                  => '',			// Serves Cuisine.
					'plm_place_menu_url'                 => '',			// Food Menu URL.
					'plm_place_order_urls'               => '',			// Order Action URL(s).
				),
			),
		);

		public static function get_version( $add_slug = false ) {

			$info =& self::$cf[ 'plugin' ][ 'wpssoplm' ];

			return $add_slug ? $info[ 'slug' ] . '-' . $info[ 'version' ] : $info[ 'version' ];
		}

		public static function set_constants( $plugin_file ) {

			if ( defined( 'WPSSOPLM_VERSION' ) ) {	// Define constants only once.

				return;
			}

			$info =& self::$cf[ 'plugin' ][ 'wpssoplm' ];

			/**
			 * Define fixed constants.
			 */
			define( 'WPSSOPLM_FILEPATH', $plugin_file );
			define( 'WPSSOPLM_PLUGINBASE', $info[ 'base' ] );	// Example: wpsso-plm/wpsso-plm.php.
			define( 'WPSSOPLM_PLUGINDIR', trailingslashit( realpath( dirname( $plugin_file ) ) ) );
			define( 'WPSSOPLM_PLUGINSLUG', $info[ 'slug' ] );	// Example: wpsso-plm.
			define( 'WPSSOPLM_URLPATH', trailingslashit( plugins_url( '', $plugin_file ) ) );
			define( 'WPSSOPLM_VERSION', $info[ 'version' ] );

			define( 'WPSSOPLM_CATEGORY_TAXONOMY', 'plm_category' );
			define( 'WPSSOPLM_PLACE_POST_TYPE', 'place' );

			/**
			 * Define variable constants.
			 */
			self::set_variable_constants();
		}

		public static function set_variable_constants( $var_const = null ) {

			if ( ! is_array( $var_const ) ) {

				$var_const = (array) self::get_variable_constants();
			}

			/**
			 * Define the variable constants, if not already defined.
			 */
			foreach ( $var_const as $name => $value ) {

				if ( ! defined( $name ) ) {

					define( $name, $value );
				}
			}
		}

		public static function get_variable_constants() {

			$var_const = array();

			/**
			 * Maybe override the default constant value with a pre-defined constant value.
			 */
			foreach ( $var_const as $name => $value ) {

				if ( defined( $name ) ) {

					$var_const[$name] = constant( $name );
				}
			}

			return $var_const;
		}

		public static function require_libs( $plugin_file ) {

			require_once WPSSOPLM_PLUGINDIR . 'lib/filters.php';
			require_once WPSSOPLM_PLUGINDIR . 'lib/place.php';
			require_once WPSSOPLM_PLUGINDIR . 'lib/register.php';

			add_filter( 'wpssoplm_load_lib', array( 'WpssoPlmConfig', 'load_lib' ), 10, 3 );
		}

		public static function load_lib( $success = false, $filespec = '', $classname = '' ) {

			if ( false === $success && ! empty( $filespec ) ) {

				$file_path = WPSSOPLM_PLUGINDIR . 'lib/' . $filespec . '.php';

				if ( file_exists( $file_path ) ) {

					require_once $file_path;

					if ( empty( $classname ) ) {

						return SucomUtil::sanitize_classname( 'wpssoplm' . $filespec, $allow_underscore = false );
					}

					return $classname;
				}
			}

			return $success;
		}
	}
}
