<?php
/**
 * License: GPLv3
 * License URI: https://www.gnu.org/licenses/gpl.txt
 * Copyright 2014-2021 Jean-Sebastien Morisset (https://wpsso.com/)
 */

if ( ! defined( 'ABSPATH' ) ) {

	die( 'These aren\'t the droids you\'re looking for.' );
}

if ( ! class_exists( 'WpssoPlmFiltersEdit' ) ) {

	class WpssoPlmFiltersEdit {

		private $p;	// Wpsso class object.
		private $a;	// WpssoPlm class object.

		/**
		 * Instantiated by WpssoPlmFilters->__construct().
		 */
		public function __construct( &$plugin, &$addon ) {

			$this->p =& $plugin;
			$this->a =& $addon;

			$this->p->util->add_plugin_filters( $this, array( 
				'metabox_sso_edit_schema_rows' => 4,
			), $prio = 2000 );	// Run after WPSSO JSON filters.
		}

		public function filter_metabox_sso_edit_schema_rows( $table_rows, $form, $head_info, $mod ) {

			if ( $this->p->debug->enabled ) {

				$this->p->debug->mark();
			}

			$weekdays =& $this->p->cf[ 'form' ][ 'weekdays' ];

			$place_types_select = $this->p->util->get_form_cache( 'place_types_select' );

			$tr_hide_place_html = '<tr class="hide_schema_place_id hide_schema_place_id_custom" style="display:none;">';

			$tr_hide_local_business_html = '<tr class="hide_schema_place_id ' . $this->p->schema->get_children_css_class( 'local.business',
				'hide_plm_place_schema_type' ) . '" style="display:none;">';

			$tr_hide_food_establishment_html = '<tr class="hide_schema_place_id ' . $this->p->schema->get_children_css_class( 'food.establishment',
				'hide_plm_place_schema_type' ) . '" style="display:none;">';

			$table_rows[ 'plm_place_schema_type' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'Place Schema Type', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_schema_type' ) . 
				'<td>' . $form->get_select( 'plm_place_schema_type', $place_types_select,
					$css_class = 'schema_type', $css_id = '', $is_assoc = true, $is_disabled = false,
						$selected = false, $event_names = array( 'on_focus_load_json', 'on_show_unhide_rows' ),
							$event_args = 'schema_place_types' ) . '</td>';

			$table_rows[ 'plm_place_name_alt' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'Place Alternate Name', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_name_alt' ) .
				'<td>' . $form->get_input( 'plm_place_name_alt', $css_class = 'long_name' ) . '</td>';

			$table_rows[ 'plm_place_street_address' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'Street Address', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_street_address' ) .  
				'<td>' . $form->get_input( 'plm_place_street_address', $css_class = 'wide' ) . '</td>';

			$table_rows[ 'plm_place_po_box_number' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'P.O. Box Number', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_po_box_number' ) .  
				'<td>' . $form->get_input( 'plm_place_po_box_number' ) . '</td>';

			$table_rows[ 'plm_place_city' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'City / Locality', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_city' ) .  
				'<td>' . $form->get_input( 'plm_place_city' ) . '</td>';

			$table_rows[ 'plm_place_region' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'State / Province', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_region' ) .  
				'<td>' . $form->get_input( 'plm_place_region' ) . '</td>';

			$table_rows[ 'plm_place_postal_code' ] = $tr_hide_place_html .
				$form->get_th_html( _x( 'Zip / Postal Code', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_postal_code' ) .  
				'<td>' . $form->get_input( 'plm_place_postal_code' ) . '</td>';

			$table_rows[ 'plm_place_country' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'Country', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_country' ) .  
				'<td>' . $form->get_select_country( 'plm_place_country' ) . '</td>';

			$table_rows[ 'plm_place_phone' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'Telephone', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_phone' ) .  
				'<td>' . $form->get_input( 'plm_place_phone' ) . '</td>';

			$table_rows[ 'plm_place_latitude' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'Place Latitude', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_latitude' ) .  
				'<td>' . $form->get_input( 'plm_place_latitude', 'is_required' ) . ' ' . 
				_x( 'decimal degrees', 'option comment', 'wpsso-plm' ) . '</td>';

			$table_rows[ 'plm_place_longitude' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'Place Longitude', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_longitude' ) .  
				'<td>' . $form->get_input( 'plm_place_longitude', 'is_required' ) . ' ' . 
				_x( 'decimal degrees', 'option comment', 'wpsso-plm' ) . '</td>';

			$table_rows[ 'plm_place_altitude' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'Place Altitude', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_altitude' ) .  
				'<td>' . $form->get_input( 'plm_place_altitude' ) . ' ' . 
				_x( 'meters above sea level', 'option comment', 'wpsso-plm' ) . '</td>';

			$table_rows[ 'plm_place_timezone' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'Place Timezone', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_timezone' ) .  
				'<td>' . $form->get_select_timezone( 'plm_place_timezone' ) . '</td>';

			/**
			 * Example $weekdays = array(
			 *	'sunday'         => 'Sunday',
			 *	'monday'         => 'Monday',
			 *	'tuesday'        => 'Tuesday',
			 *	'wednesday'      => 'Wednesday',
			 *	'thursday'       => 'Thursday',
			 *	'friday'         => 'Friday',
			 *	'saturday'       => 'Saturday',
			 *	'publicholidays' => 'Public Holidays',
			 * );
			 */
			$days_html = '<table class="business_hours">';

			foreach ( $weekdays as $day_name => $day_label ) {

				$day_opt_pre   = 'plm_place_day_' . $day_name;
				$open_opt_key  = $day_opt_pre . '_open';
				$close_opt_key = $day_opt_pre . '_close';

				// translators: Please ignore - translation uses a different text domain.
				$day_label_transl = _x( $day_label, 'option value', 'wpsso' );

				$days_html .= '<tr>' .
					'<td class="weekday"><p>' . $day_label_transl . '</p></td>' .
					'<td align="right"><p>' . __( 'Opens at', 'wpsso-plm' ) . '</p></td>' .
					'<td>' . $form->get_select_time_none( $open_opt_key ) . '</td>' .
					'<td align="right"><p>' . __( 'and closes at', 'wpsso-plm' ) . '</p></td>' .
					'<td>' . $form->get_select_time_none( $close_opt_key ) . '</td>' .
					'</tr>';
			}

			$days_html .= '<tr>' .
				'<td><p>' . __( 'Every Midday', 'wpsso-plm' ) . '</p></td>' .
				'<td align="right"><p>' . __( 'Closes at', 'wpsso-plm' ) . '</p></td>' .
				'<td>' . $form->get_select_time_none( 'plm_place_midday_close' ) . '</td>' .
				'<td align="right"><p>' . __( 'and re-opens at', 'wpsso-plm' ) . '</p></td>' .
				'<td>' . $form->get_select_time_none( 'plm_place_midday_open' ) . '</td>' .
				'</tr>';

			$days_html .= '</table>';

			$table_rows[ 'plm_place_days' ] = $tr_hide_place_html .
				$form->get_th_html( _x( 'Open Days / Hours', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_days' ) .
				'<td>' . $days_html . '</td>';

			$table_rows[ 'plm_place_season_dates' ] = $tr_hide_place_html . 
				$form->get_th_html( _x( 'Seasonal Dates', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_season_dates' ) .  
				'<td><p style="margin-bottom:0;">' . 
				__( 'Open from', 'wpsso-plm' ) . ' ' .	// Keep it short for translations.
				$form->get_input_date( 'plm_place_season_from_date' ) . ' ' . 
				__( 'until', 'wpsso-plm' ) . ' ' .	// Keep it short for translations.
				$form->get_input_date( 'plm_place_season_to_date' ) . ' ' .
				__( 'inclusively', 'wpsso-plm' ) .	// Keep it short for translations.
				'</p></td>';

			$table_rows[ 'subsection_local_business' ] = $tr_hide_local_business_html . '<th class="medium"></th>' . 
				'<td class="subsection"><h5>' . _x( 'Local Business', 'metabox title', 'wpsso-plm' ) . '</h5></td>';

			$table_rows[ 'plm_place_service_radius' ] = $tr_hide_local_business_html . 
				$form->get_th_html( _x( 'Service Radius', 'option label', 'wpsso-plm' ),
			$css_class = 'medium', $css_id = 'plm_place_service_radius' ) .  
				'<td>' . $form->get_input( 'plm_place_service_radius',
					$css_class = 'short' ) . ' ' . 
				_x( 'meters from location', 'option comment', 'wpsso-plm' ) . '</td>';

			$table_rows[ 'plm_place_currencies_accepted' ] = $tr_hide_local_business_html . 
				$form->get_th_html( _x( 'Currencies Accepted', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_currencies_accepted' ) .  
				'<td>' . $form->get_input( 'plm_place_currencies_accepted' ) . '</td>';

			$table_rows[ 'plm_place_payment_accepted' ] = $tr_hide_local_business_html . 
				$form->get_th_html( _x( 'Payment Accepted', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_payment_accepted' ) .  
				'<td>' . $form->get_input( 'plm_place_payment_accepted' ) . '</td>';

			$table_rows[ 'plm_place_price_range' ] = $tr_hide_local_business_html . 
				$form->get_th_html( _x( 'Price Range', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_price_range' ) .  
				'<td>' . $form->get_input( 'plm_place_price_range' ) . '</td>';

			$table_rows[ 'subsection_food_establishment' ] = $tr_hide_food_establishment_html . '<th class="medium"></th>' . 
				'<td class="subsection"><h5>' . _x( 'Food Establishment', 'metabox title', 'wpsso-plm' ) . '</h5></td>';

			$table_rows[ 'plm_place_accept_res' ] = $tr_hide_food_establishment_html . 
				$form->get_th_html( _x( 'Accepts Reservations', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_accept_res' ) .  
				'<td>' . $form->get_checkbox( 'plm_place_accept_res' ) . '</td>';

			$table_rows[ 'plm_place_cuisine' ] = $tr_hide_food_establishment_html . 
				$form->get_th_html( _x( 'Serves Cuisine', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_cuisine' ) .  
				'<td>' . $form->get_input( 'plm_place_cuisine' ) . '</td>';

			$table_rows[ 'plm_place_menu_url' ] = $tr_hide_food_establishment_html . 
				$form->get_th_html( _x( 'Food Menu URL', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_menu_url' ) .  
				'<td>' . $form->get_input( 'plm_place_menu_url', 'wide' ) . '</td>';

			$table_rows[ 'plm_place_order_urls' ] = $tr_hide_food_establishment_html . 
				$form->get_th_html( _x( 'Order Action URL(s)', 'option label', 'wpsso-plm' ),
					$css_class = 'medium', $css_id = 'plm_place_order_urls' ) .  
				'<td>' . $form->get_input( 'plm_place_order_urls', 'wide' ) . '</td>';

			return $table_rows;
		}
	}
}
